@@ -56,9 +56,10 @@ class DataFileProperty:
             return False
 
     def _load_and_save(self) -> bool:
-        self.sync()
+
         if self.tar_exists():
             return False
+
         logger.info(f'download for {self.file_path_tar(absolute=False)}')
         exchan = LoadDataKline(self.exchange)
         exchan.table.delete_all()
@@ -77,10 +78,13 @@ class DataFileProperty:
 
     def _load(self, start_end_fun):
         index = 1
-        while index < 10:
-            self.start_date, self.end_date = start_end_fun(-index)
+        for i in range(1, 10000):
+            self.start_date, self.end_date = start_end_fun(-i)
             if self._load_and_save():
+                self.sync()
                 index += 1
+            if index > 100:
+                break
 
     def load(self):
         if self.freq == 'daily':
